==> kdelibs-4.4.3-x86_64-2_slack13.1.txz: install/doinst.sh <==

if [ -x /usr/bin/update-desktop-database ]; then
  /usr/bin/update-desktop-database /usr/share/applications >/dev/null 2>&1
fi

if [ -x usr/bin/update-mime-database ]; then
  /usr/bin/update-mime-database /usr/share/mime >/dev/null 2>&1
fi

( cd usr/share/doc/HTML/en/sonnet ; rm -rf common )
( cd usr/share/doc/HTML/en/sonnet ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kioslave/http ; rm -rf common )
( cd usr/share/doc/HTML/en/kioslave/http ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kioslave/rlogin ; rm -rf common )
( cd usr/share/doc/HTML/en/kioslave/rlogin ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kioslave/webdav ; rm -rf common )
( cd usr/share/doc/HTML/en/kioslave/webdav ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kioslave/help ; rm -rf common )
( cd usr/share/doc/HTML/en/kioslave/help ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kioslave/ftp ; rm -rf common )
( cd usr/share/doc/HTML/en/kioslave/ftp ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kioslave/file ; rm -rf common )
( cd usr/share/doc/HTML/en/kioslave/file ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kioslave/data ; rm -rf common )
( cd usr/share/doc/HTML/en/kioslave/data ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kioslave/mailto ; rm -rf common )
( cd usr/share/doc/HTML/en/kioslave/mailto ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kioslave/telnet ; rm -rf common )
( cd usr/share/doc/HTML/en/kioslave/telnet ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/lib64 ; rm -rf libkpty.so.4 )
( cd usr/lib64 ; ln -sf libkpty.so.4.4.0 libkpty.so.4 )
( cd usr/lib64 ; rm -rf libkparts.so.4 )
( cd usr/lib64 ; ln -sf libkparts.so.4.4.0 libkparts.so.4 )
( cd usr/lib64 ; rm -rf libnepomuk.so.4 )
( cd usr/lib64 ; ln -sf libnepomuk.so.4.4.0 libnepomuk.so.4 )
( cd usr/lib64 ; rm -rf libkfile.so.4 )
( cd usr/lib64 ; ln -sf libkfile.so.4.4.0 libkfile.so.4 )
( cd usr/lib64 ; rm -rf libkdeui.so )
( cd usr/lib64 ; ln -sf libkdeui.so.5 libkdeui.so )
( cd usr/lib64 ; rm -rf libkimproxy.so.4 )
( cd usr/lib64 ; ln -sf libkimproxy.so.4.4.0 libkimproxy.so.4 )
( cd usr/lib64 ; rm -rf libkjsapi.so )
( cd usr/lib64 ; ln -sf libkjsapi.so.4 libkjsapi.so )
( cd usr/lib64 ; rm -rf libkrossui.so )
( cd usr/lib64 ; ln -sf libkrossui.so.4 libkrossui.so )
( cd usr/lib64 ; rm -rf libkmediaplayer.so )
( cd usr/lib64 ; ln -sf libkmediaplayer.so.4 libkmediaplayer.so )
( cd usr/lib64/kde4/plugins/script ; rm -rf libkrossqtsplugin.so.4 )
( cd usr/lib64/kde4/plugins/script ; ln -sf libkrossqtsplugin.so.4.4.0 libkrossqtsplugin.so.4 )
( cd usr/lib64/kde4/plugins/script ; rm -rf libkrossqtsplugin.so )
( cd usr/lib64/kde4/plugins/script ; ln -sf libkrossqtsplugin.so.4 libkrossqtsplugin.so )
( cd usr/lib64/kde4/libexec ; rm -rf filesharelist )
( cd usr/lib64/kde4/libexec ; ln -sf /usr/lib64/kde4/libexec/fileshareset filesharelist )
( cd usr/lib64 ; rm -rf libkdefakes.so.5 )
( cd usr/lib64 ; ln -sf libkdefakes.so.5.4.0 libkdefakes.so.5 )
( cd usr/lib64 ; rm -rf libkimproxy.so )
( cd usr/lib64 ; ln -sf libkimproxy.so.4 libkimproxy.so )
( cd usr/lib64 ; rm -rf libkpty.so )
( cd usr/lib64 ; ln -sf libkpty.so.4 libkpty.so )
( cd usr/lib64 ; rm -rf libknewstuff2.so )
( cd usr/lib64 ; ln -sf libknewstuff2.so.4 libknewstuff2.so )
( cd usr/lib64 ; rm -rf libkde3support.so )
( cd usr/lib64 ; ln -sf libkde3support.so.4 libkde3support.so )
( cd usr/lib64 ; rm -rf libkunitconversion.so.4 )
( cd usr/lib64 ; ln -sf libkunitconversion.so.4.4.0 libkunitconversion.so.4 )
( cd usr/lib64 ; rm -rf libkfile.so )
( cd usr/lib64 ; ln -sf libkfile.so.4 libkfile.so )
( cd usr/lib64 ; rm -rf libkdecore.so )
( cd usr/lib64 ; ln -sf libkdecore.so.5 libkdecore.so )
( cd usr/lib64 ; rm -rf libkutils.so.4 )
( cd usr/lib64 ; ln -sf libkutils.so.4.4.0 libkutils.so.4 )
( cd usr/lib64 ; rm -rf libkdesu.so )
( cd usr/lib64 ; ln -sf libkdesu.so.5 libkdesu.so )
( cd usr/lib64 ; rm -rf libktexteditor.so.4 )
( cd usr/lib64 ; ln -sf libktexteditor.so.4.4.0 libktexteditor.so.4 )
( cd usr/lib64 ; rm -rf libkunittest.so.4 )
( cd usr/lib64 ; ln -sf libkunittest.so.4.4.0 libkunittest.so.4 )
( cd usr/lib64 ; rm -rf libthreadweaver.so.4 )
( cd usr/lib64 ; ln -sf libthreadweaver.so.4.4.0 libthreadweaver.so.4 )
( cd usr/lib64 ; rm -rf libkio.so.5 )
( cd usr/lib64 ; ln -sf libkio.so.5.4.0 libkio.so.5 )
( cd usr/lib64 ; rm -rf libkjsembed.so )
( cd usr/lib64 ; ln -sf libkjsembed.so.4 libkjsembed.so )
( cd usr/lib64 ; rm -rf libknewstuff3.so.4 )
( cd usr/lib64 ; ln -sf libknewstuff3.so.4.4.0 libknewstuff3.so.4 )
( cd usr/lib64 ; rm -rf libkunittest.so )
( cd usr/lib64 ; ln -sf libkunittest.so.4 libkunittest.so )
( cd usr/lib64 ; rm -rf libsolid.so.4 )
( cd usr/lib64 ; ln -sf libsolid.so.4.4.0 libsolid.so.4 )
( cd usr/lib64 ; rm -rf libplasma.so.3 )
( cd usr/lib64 ; ln -sf libplasma.so.3.0.0 libplasma.so.3 )
( cd usr/lib64 ; rm -rf libkjsembed.so.4 )
( cd usr/lib64 ; ln -sf libkjsembed.so.4.4.0 libkjsembed.so.4 )
( cd usr/lib64 ; rm -rf libkdeui.so.5 )
( cd usr/lib64 ; ln -sf libkdeui.so.5.4.0 libkdeui.so.5 )
( cd usr/lib64 ; rm -rf libkparts.so )
( cd usr/lib64 ; ln -sf libkparts.so.4 libkparts.so )
( cd usr/lib64 ; rm -rf libkdefakes.so )
( cd usr/lib64 ; ln -sf libkdefakes.so.5 libkdefakes.so )
( cd usr/lib64 ; rm -rf libknewstuff2.so.4 )
( cd usr/lib64 ; ln -sf libknewstuff2.so.4.4.0 libknewstuff2.so.4 )
( cd usr/lib64 ; rm -rf libknewstuff3.so )
( cd usr/lib64 ; ln -sf libknewstuff3.so.4 libknewstuff3.so )
( cd usr/lib64 ; rm -rf libkrossui.so.4 )
( cd usr/lib64 ; ln -sf libkrossui.so.4.4.0 libkrossui.so.4 )
( cd usr/lib64 ; rm -rf libkdesu.so.5 )
( cd usr/lib64 ; ln -sf libkdesu.so.5.4.0 libkdesu.so.5 )
( cd usr/lib64 ; rm -rf libkdnssd.so )
( cd usr/lib64 ; ln -sf libkdnssd.so.4 libkdnssd.so )
( cd usr/lib64 ; rm -rf libkdnssd.so.4 )
( cd usr/lib64 ; ln -sf libkdnssd.so.4.4.0 libkdnssd.so.4 )
( cd usr/lib64 ; rm -rf libkio.so )
( cd usr/lib64 ; ln -sf libkio.so.5 libkio.so )
( cd usr/lib64 ; rm -rf libkhtml.so.5 )
( cd usr/lib64 ; ln -sf libkhtml.so.5.4.0 libkhtml.so.5 )
( cd usr/lib64 ; rm -rf libnepomukquery.so.4 )
( cd usr/lib64 ; ln -sf libnepomukquery.so.4.4.0 libnepomukquery.so.4 )
( cd usr/lib64 ; rm -rf libkde3support.so.4 )
( cd usr/lib64 ; ln -sf libkde3support.so.4.4.0 libkde3support.so.4 )
( cd usr/lib64 ; rm -rf libplasma.so )
( cd usr/lib64 ; ln -sf libplasma.so.3 libplasma.so )
( cd usr/lib64 ; rm -rf libthreadweaver.so )
( cd usr/lib64 ; ln -sf libthreadweaver.so.4 libthreadweaver.so )
( cd usr/lib64 ; rm -rf libknotifyconfig.so )
( cd usr/lib64 ; ln -sf libknotifyconfig.so.4 libknotifyconfig.so )
( cd usr/lib64 ; rm -rf libkhtml.so )
( cd usr/lib64 ; ln -sf libkhtml.so.5 libkhtml.so )
( cd usr/lib64 ; rm -rf libkntlm.so.4 )
( cd usr/lib64 ; ln -sf libkntlm.so.4.4.0 libkntlm.so.4 )
( cd usr/lib64 ; rm -rf libkdewebkit.so.5 )
( cd usr/lib64 ; ln -sf libkdewebkit.so.5.4.0 libkdewebkit.so.5 )
( cd usr/lib64 ; rm -rf libnepomuk.so )
( cd usr/lib64 ; ln -sf libnepomuk.so.4 libnepomuk.so )
( cd usr/lib64 ; rm -rf libkjs.so.4 )
( cd usr/lib64 ; ln -sf libkjs.so.4.4.0 libkjs.so.4 )
( cd usr/lib64 ; rm -rf libkntlm.so )
( cd usr/lib64 ; ln -sf libkntlm.so.4 libkntlm.so )
( cd usr/lib64 ; rm -rf libsolid.so )
( cd usr/lib64 ; ln -sf libsolid.so.4 libsolid.so )
( cd usr/lib64 ; rm -rf libkmediaplayer.so.4 )
( cd usr/lib64 ; ln -sf libkmediaplayer.so.4.4.0 libkmediaplayer.so.4 )
( cd usr/lib64 ; rm -rf libkunitconversion.so )
( cd usr/lib64 ; ln -sf libkunitconversion.so.4 libkunitconversion.so )
( cd usr/lib64 ; rm -rf libkutils.so )
( cd usr/lib64 ; ln -sf libkutils.so.4 libkutils.so )
( cd usr/lib64 ; rm -rf libkdecore.so.5 )
( cd usr/lib64 ; ln -sf libkdecore.so.5.4.0 libkdecore.so.5 )
( cd usr/lib64 ; rm -rf libkrosscore.so )
( cd usr/lib64 ; ln -sf libkrosscore.so.4 libkrosscore.so )
( cd usr/lib64 ; rm -rf libkdewebkit.so )
( cd usr/lib64 ; ln -sf libkdewebkit.so.5 libkdewebkit.so )
( cd usr/lib64 ; rm -rf libkjs.so )
( cd usr/lib64 ; ln -sf libkjs.so.4 libkjs.so )
( cd usr/lib64 ; rm -rf libktexteditor.so )
( cd usr/lib64 ; ln -sf libktexteditor.so.4 libktexteditor.so )
( cd usr/lib64 ; rm -rf libkjsapi.so.4 )
( cd usr/lib64 ; ln -sf libkjsapi.so.4.4.0 libkjsapi.so.4 )
( cd usr/lib64 ; rm -rf libkrosscore.so.4 )
( cd usr/lib64 ; ln -sf libkrosscore.so.4.4.0 libkrosscore.so.4 )
( cd usr/lib64 ; rm -rf libknotifyconfig.so.4 )
( cd usr/lib64 ; ln -sf libknotifyconfig.so.4.4.0 libknotifyconfig.so.4 )
( cd usr/lib64 ; rm -rf libnepomukquery.so )
( cd usr/lib64 ; ln -sf libnepomukquery.so.4 libnepomukquery.so )

==> kdelibs-4.5.5-x86_64-3_slack13.37.txz: install/doinst.sh <==

if [ -x /usr/bin/update-desktop-database ]; then
  /usr/bin/update-desktop-database /usr/share/applications >/dev/null 2>&1
fi

if [ -x usr/bin/update-mime-database ]; then
  /usr/bin/update-mime-database /usr/share/mime >/dev/null 2>&1
fi

( cd usr/share/doc/HTML/en/kioslave/file ; rm -rf common )
( cd usr/share/doc/HTML/en/kioslave/file ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kioslave/ftp ; rm -rf common )
( cd usr/share/doc/HTML/en/kioslave/ftp ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kioslave/rlogin ; rm -rf common )
( cd usr/share/doc/HTML/en/kioslave/rlogin ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kioslave/mailto ; rm -rf common )
( cd usr/share/doc/HTML/en/kioslave/mailto ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kioslave/help ; rm -rf common )
( cd usr/share/doc/HTML/en/kioslave/help ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kioslave/webdav ; rm -rf common )
( cd usr/share/doc/HTML/en/kioslave/webdav ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kioslave/data ; rm -rf common )
( cd usr/share/doc/HTML/en/kioslave/data ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kioslave/telnet ; rm -rf common )
( cd usr/share/doc/HTML/en/kioslave/telnet ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kioslave/http ; rm -rf common )
( cd usr/share/doc/HTML/en/kioslave/http ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/sonnet ; rm -rf common )
( cd usr/share/doc/HTML/en/sonnet ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/lib64 ; rm -rf libkdecore.so.5 )
( cd usr/lib64 ; ln -sf libkdecore.so.5.5.0 libkdecore.so.5 )
( cd usr/lib64 ; rm -rf libkemoticons.so )
( cd usr/lib64 ; ln -sf libkemoticons.so.4 libkemoticons.so )
( cd usr/lib64 ; rm -rf libthreadweaver.so )
( cd usr/lib64 ; ln -sf libthreadweaver.so.4 libthreadweaver.so )
( cd usr/lib64 ; rm -rf libkpty.so )
( cd usr/lib64 ; ln -sf libkpty.so.4 libkpty.so )
( cd usr/lib64 ; rm -rf libthreadweaver.so.4 )
( cd usr/lib64 ; ln -sf libthreadweaver.so.4.5.0 libthreadweaver.so.4 )
( cd usr/lib64 ; rm -rf libkutils.so )
( cd usr/lib64 ; ln -sf libkutils.so.4 libkutils.so )
( cd usr/lib64 ; rm -rf libnepomuk.so.4 )
( cd usr/lib64 ; ln -sf libnepomuk.so.4.5.0 libnepomuk.so.4 )
( cd usr/lib64 ; rm -rf libkdesu.so )
( cd usr/lib64 ; ln -sf libkdesu.so.5 libkdesu.so )
( cd usr/lib64 ; rm -rf libkmediaplayer.so.4 )
( cd usr/lib64 ; ln -sf libkmediaplayer.so.4.5.0 libkmediaplayer.so.4 )
( cd usr/lib64 ; rm -rf libkdewebkit.so )
( cd usr/lib64 ; ln -sf libkdewebkit.so.5 libkdewebkit.so )
( cd usr/lib64 ; rm -rf libkrossui.so.4 )
( cd usr/lib64 ; ln -sf libkrossui.so.4.5.0 libkrossui.so.4 )
( cd usr/lib64 ; rm -rf libkcmutils.so )
( cd usr/lib64 ; ln -sf libkcmutils.so.4 libkcmutils.so )
( cd usr/lib64 ; rm -rf libkjs.so )
( cd usr/lib64 ; ln -sf libkjs.so.4 libkjs.so )
( cd usr/lib64 ; rm -rf libkparts.so.4 )
( cd usr/lib64 ; ln -sf libkparts.so.4.5.0 libkparts.so.4 )
( cd usr/lib64 ; rm -rf libnepomuk.so )
( cd usr/lib64 ; ln -sf libnepomuk.so.4 libnepomuk.so )
( cd usr/lib64 ; rm -rf libnepomukquery.so.4 )
( cd usr/lib64 ; ln -sf libnepomukquery.so.4.5.0 libnepomukquery.so.4 )
( cd usr/lib64 ; rm -rf libkdnssd.so.4 )
( cd usr/lib64 ; ln -sf libkdnssd.so.4.5.0 libkdnssd.so.4 )
( cd usr/lib64 ; rm -rf libkunittest.so )
( cd usr/lib64 ; ln -sf libkunittest.so.4 libkunittest.so )
( cd usr/lib64 ; rm -rf libkutils.so.4 )
( cd usr/lib64 ; ln -sf libkutils.so.4.5.0 libkutils.so.4 )
( cd usr/lib64 ; rm -rf libknewstuff3.so.4 )
( cd usr/lib64 ; ln -sf libknewstuff3.so.4.5.0 libknewstuff3.so.4 )
( cd usr/lib64 ; rm -rf libkntlm.so.4 )
( cd usr/lib64 ; ln -sf libkntlm.so.4.5.0 libkntlm.so.4 )
( cd usr/lib64 ; rm -rf libkdeui.so.5 )
( cd usr/lib64 ; ln -sf libkdeui.so.5.5.0 libkdeui.so.5 )
( cd usr/lib64 ; rm -rf libsolid.so )
( cd usr/lib64 ; ln -sf libsolid.so.4 libsolid.so )
( cd usr/lib64 ; rm -rf libkdecore.so )
( cd usr/lib64 ; ln -sf libkdecore.so.5 libkdecore.so )
( cd usr/lib64 ; rm -rf libktexteditor.so )
( cd usr/lib64 ; ln -sf libktexteditor.so.4 libktexteditor.so )
( cd usr/lib64 ; rm -rf libkfile.so.4 )
( cd usr/lib64 ; ln -sf libkfile.so.4.5.0 libkfile.so.4 )
( cd usr/lib64 ; rm -rf libkio.so )
( cd usr/lib64 ; ln -sf libkio.so.5 libkio.so )
( cd usr/lib64 ; rm -rf libkdefakes.so.5 )
( cd usr/lib64 ; ln -sf libkdefakes.so.5.5.0 libkdefakes.so.5 )
( cd usr/lib64 ; rm -rf libkde3support.so )
( cd usr/lib64 ; ln -sf libkde3support.so.4 libkde3support.so )
( cd usr/lib64/kde4/libexec ; rm -rf filesharelist )
( cd usr/lib64/kde4/libexec ; ln -sf /usr/lib64/kde4/libexec/fileshareset filesharelist )
( cd usr/lib64/kde4/plugins/script ; rm -rf libkrossqtsplugin.so )
( cd usr/lib64/kde4/plugins/script ; ln -sf libkrossqtsplugin.so.4 libkrossqtsplugin.so )
( cd usr/lib64/kde4/plugins/script ; rm -rf libkrossqtsplugin.so.4 )
( cd usr/lib64/kde4/plugins/script ; ln -sf libkrossqtsplugin.so.4.5.0 libkrossqtsplugin.so.4 )
( cd usr/lib64 ; rm -rf libkjs.so.4 )
( cd usr/lib64 ; ln -sf libkjs.so.4.5.0 libkjs.so.4 )
( cd usr/lib64 ; rm -rf libknewstuff3.so )
( cd usr/lib64 ; ln -sf libknewstuff3.so.4 libknewstuff3.so )
( cd usr/lib64 ; rm -rf libsolid.so.4 )
( cd usr/lib64 ; ln -sf libsolid.so.4.5.0 libsolid.so.4 )
( cd usr/lib64 ; rm -rf libkatepartinterfaces.so.4 )
( cd usr/lib64 ; ln -sf libkatepartinterfaces.so.4.5.0 libkatepartinterfaces.so.4 )
( cd usr/lib64 ; rm -rf libktexteditor.so.4 )
( cd usr/lib64 ; ln -sf libktexteditor.so.4.5.0 libktexteditor.so.4 )
( cd usr/lib64 ; rm -rf libkio.so.5 )
( cd usr/lib64 ; ln -sf libkio.so.5.5.0 libkio.so.5 )
( cd usr/lib64 ; rm -rf libkparts.so )
( cd usr/lib64 ; ln -sf libkparts.so.4 libkparts.so )
( cd usr/lib64 ; rm -rf libkatepartinterfaces.so )
( cd usr/lib64 ; ln -sf libkatepartinterfaces.so.4 libkatepartinterfaces.so )
( cd usr/lib64 ; rm -rf libkunitconversion.so )
( cd usr/lib64 ; ln -sf libkunitconversion.so.4 libkunitconversion.so )
( cd usr/lib64 ; rm -rf libkdefakes.so )
( cd usr/lib64 ; ln -sf libkdefakes.so.5 libkdefakes.so )
( cd usr/lib64 ; rm -rf libkidletime.so.4 )
( cd usr/lib64 ; ln -sf libkidletime.so.4.5.0 libkidletime.so.4 )
( cd usr/lib64 ; rm -rf libkidletime.so )
( cd usr/lib64 ; ln -sf libkidletime.so.4 libkidletime.so )
( cd usr/lib64 ; rm -rf libkrosscore.so.4 )
( cd usr/lib64 ; ln -sf libkrosscore.so.4.5.0 libkrosscore.so.4 )
( cd usr/lib64 ; rm -rf libkjsapi.so )
( cd usr/lib64 ; ln -sf libkjsapi.so.4 libkjsapi.so )
( cd usr/lib64 ; rm -rf libknewstuff2.so )
( cd usr/lib64 ; ln -sf libknewstuff2.so.4 libknewstuff2.so )
( cd usr/lib64 ; rm -rf libkprintutils.so.4 )
( cd usr/lib64 ; ln -sf libkprintutils.so.4.5.0 libkprintutils.so.4 )
( cd usr/lib64 ; rm -rf libkfile.so )
( cd usr/lib64 ; ln -sf libkfile.so.4 libkfile.so )
( cd usr/lib64 ; rm -rf libkrossui.so )
( cd usr/lib64 ; ln -sf libkrossui.so.4 libkrossui.so )
( cd usr/lib64 ; rm -rf libkjsembed.so.4 )
( cd usr/lib64 ; ln -sf libkjsembed.so.4.5.0 libkjsembed.so.4 )
( cd usr/lib64 ; rm -rf libkdewebkit.so.5 )
( cd usr/lib64 ; ln -sf libkdewebkit.so.5.5.0 libkdewebkit.so.5 )
( cd usr/lib64 ; rm -rf libkhtml.so )
( cd usr/lib64 ; ln -sf libkhtml.so.5 libkhtml.so )
( cd usr/lib64 ; rm -rf libknotifyconfig.so )
( cd usr/lib64 ; ln -sf libknotifyconfig.so.4 libknotifyconfig.so )
( cd usr/lib64 ; rm -rf libkunittest.so.4 )
( cd usr/lib64 ; ln -sf libkunittest.so.4.5.0 libkunittest.so.4 )
( cd usr/lib64 ; rm -rf libkhtml.so.5 )
( cd usr/lib64 ; ln -sf libkhtml.so.5.5.0 libkhtml.so.5 )
( cd usr/lib64 ; rm -rf libkjsapi.so.4 )
( cd usr/lib64 ; ln -sf libkjsapi.so.4.5.0 libkjsapi.so.4 )
( cd usr/lib64 ; rm -rf libplasma.so )
( cd usr/lib64 ; ln -sf libplasma.so.3 libplasma.so )
( cd usr/lib64 ; rm -rf libkemoticons.so.4 )
( cd usr/lib64 ; ln -sf libkemoticons.so.4.5.0 libkemoticons.so.4 )
( cd usr/lib64 ; rm -rf libkdesu.so.5 )
( cd usr/lib64 ; ln -sf libkdesu.so.5.5.0 libkdesu.so.5 )
( cd usr/lib64 ; rm -rf libkrosscore.so )
( cd usr/lib64 ; ln -sf libkrosscore.so.4 libkrosscore.so )
( cd usr/lib64 ; rm -rf libplasma.so.3 )
( cd usr/lib64 ; ln -sf libplasma.so.3.0.0 libplasma.so.3 )
( cd usr/lib64 ; rm -rf libkpty.so.4 )
( cd usr/lib64 ; ln -sf libkpty.so.4.5.0 libkpty.so.4 )
( cd usr/lib64 ; rm -rf libkunitconversion.so.4 )
( cd usr/lib64 ; ln -sf libkunitconversion.so.4.5.0 libkunitconversion.so.4 )
( cd usr/lib64 ; rm -rf libkjsembed.so )
( cd usr/lib64 ; ln -sf libkjsembed.so.4 libkjsembed.so )
( cd usr/lib64 ; rm -rf libkdnssd.so )
( cd usr/lib64 ; ln -sf libkdnssd.so.4 libkdnssd.so )
( cd usr/lib64 ; rm -rf libkprintutils.so )
( cd usr/lib64 ; ln -sf libkprintutils.so.4 libkprintutils.so )
( cd usr/lib64 ; rm -rf libnepomukquery.so )
( cd usr/lib64 ; ln -sf libnepomukquery.so.4 libnepomukquery.so )
( cd usr/lib64 ; rm -rf libkimproxy.so.4 )
( cd usr/lib64 ; ln -sf libkimproxy.so.4.5.0 libkimproxy.so.4 )
( cd usr/lib64 ; rm -rf libkcmutils.so.4 )
( cd usr/lib64 ; ln -sf libkcmutils.so.4.5.0 libkcmutils.so.4 )
( cd usr/lib64 ; rm -rf libkntlm.so )
( cd usr/lib64 ; ln -sf libkntlm.so.4 libkntlm.so )
( cd usr/lib64 ; rm -rf libkimproxy.so )
( cd usr/lib64 ; ln -sf libkimproxy.so.4 libkimproxy.so )
( cd usr/lib64 ; rm -rf libkdeui.so )
( cd usr/lib64 ; ln -sf libkdeui.so.5 libkdeui.so )
( cd usr/lib64 ; rm -rf libknewstuff2.so.4 )
( cd usr/lib64 ; ln -sf libknewstuff2.so.4.5.0 libknewstuff2.so.4 )
( cd usr/lib64 ; rm -rf libkde3support.so.4 )
( cd usr/lib64 ; ln -sf libkde3support.so.4.5.0 libkde3support.so.4 )
( cd usr/lib64 ; rm -rf libkmediaplayer.so )
( cd usr/lib64 ; ln -sf libkmediaplayer.so.4 libkmediaplayer.so )
( cd usr/lib64 ; rm -rf libknotifyconfig.so.4 )
( cd usr/lib64 ; ln -sf libknotifyconfig.so.4.5.0 libknotifyconfig.so.4 )
